==> identity-editor-1.1.11-sources.jar: io/intino/amidas/identityeditor/box/ui/displays/templates/AbstractIdentityViewer.java <==
package io.intino.amidas.identityeditor.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.amidas.identityeditor.box.ui.*;

import io.intino.amidas.identityeditor.box.IdentityEditorBox;

import io.intino.amidas.identityeditor.box.ui.displays.templates.*;



import io.intino.amidas.identityeditor.box.ui.displays.notifiers.IdentityViewerNotifier;

public abstract class AbstractIdentityViewer<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<IdentityViewerNotifier, java.lang.Void, B> {
	public EmptyLayer emptyLayer;
	public IdentityViewer.EmptyLayer. EmptyText emptyText;
	public LoadingLayer loadingLayer;
	public IdentityViewer.LoadingLayer. Identity_7_92_1339785223 Identity_7_92_1339785223;
	public MainLayer mainLayer;
	public IdentityViewer.MainLayer. FeaturesPanel featuresPanel;
	public IdentityViewer.MainLayer.FeaturesPanel. FeaturesTitle featuresTitle;
	public IdentityViewer.MainLayer.FeaturesPanel. FeaturesStamp featuresStamp;
	public IdentityViewer.MainLayer. CredentialsPanel credentialsPanel;
	public IdentityViewer.MainLayer.CredentialsPanel. CredentialsTitle credentialsTitle;
	public IdentityViewer.MainLayer.CredentialsPanel. CredentialsStamp credentialsStamp;
	public IdentityViewer.MainLayer. RolesPanel rolesPanel;
	public IdentityViewer.MainLayer.RolesPanel. RolesTitle rolesTitle;
	public IdentityViewer.MainLayer.RolesPanel. RolesStamp rolesStamp;

    public AbstractIdentityViewer(B box) {
        super(box);
        id("identityViewer");
    }

    @Override
	public void init() {
		super.init();
		if (emptyLayer == null) emptyLayer = register(new EmptyLayer(box()).<EmptyLayer>id("a_755652684").owner(AbstractIdentityViewer.this));
		if (emptyLayer != null) emptyText = emptyLayer.emptyText;
		if (loadingLayer == null) loadingLayer = register(new LoadingLayer(box()).<LoadingLayer>id("a1199389989").owner(AbstractIdentityViewer.this));
		if (loadingLayer != null) Identity_7_92_1339785223 = loadingLayer.Identity_7_92_1339785223;
		if (mainLayer == null) mainLayer = register(new MainLayer(box()).<MainLayer>id("a_258747032").owner(AbstractIdentityViewer.this));
		if (mainLayer != null) featuresPanel = mainLayer.featuresPanel;
		if (featuresPanel != null) featuresTitle = mainLayer.featuresPanel.featuresTitle;
		if (featuresPanel != null) featuresStamp = mainLayer.featuresPanel.featuresStamp;
		if (mainLayer != null) credentialsPanel = mainLayer.credentialsPanel;
		if (credentialsPanel != null) credentialsTitle = mainLayer.credentialsPanel.credentialsTitle;
		if (credentialsPanel != null) credentialsStamp = mainLayer.credentialsPanel.credentialsStamp;
		if (mainLayer != null) rolesPanel = mainLayer.rolesPanel;
		if (rolesPanel != null) rolesTitle = mainLayer.rolesPanel.rolesTitle;
		if (rolesPanel != null) rolesStamp = mainLayer.rolesPanel.rolesStamp;
	}

	public class EmptyLayer extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public IdentityViewer.EmptyLayer. EmptyText emptyText;

		public EmptyLayer(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (emptyText == null) emptyText = register(new EmptyText(box()).<EmptyText>id("a_1732484785").owner(AbstractIdentityViewer.this));
		}

		public class EmptyText extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public EmptyText(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}

	public class LoadingLayer extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public IdentityViewer.LoadingLayer. Identity_7_92_1339785223 Identity_7_92_1339785223;

		public LoadingLayer(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (Identity_7_92_1339785223 == null) Identity_7_92_1339785223 = register(new Identity_7_92_1339785223(box()).<Identity_7_92_1339785223>id("a_128396962").owner(AbstractIdentityViewer.this));
		}

		public class Identity_7_92_1339785223 extends io.intino.alexandria.ui.displays.components.Spinner<io.intino.alexandria.ui.displays.notifiers.SpinnerNotifier, B>  {

			public Identity_7_92_1339785223(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}

	public class MainLayer extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public IdentityViewer.MainLayer. FeaturesPanel featuresPanel;
		public IdentityViewer.MainLayer. CredentialsPanel credentialsPanel;
		public IdentityViewer.MainLayer. RolesPanel rolesPanel;

		public MainLayer(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (featuresPanel == null) featuresPanel = register(new FeaturesPanel(box()).<FeaturesPanel>id("a_1348836048").owner(AbstractIdentityViewer.this));
			if (credentialsPanel == null) credentialsPanel = register(new CredentialsPanel(box()).<CredentialsPanel>id("a_1794867617").owner(AbstractIdentityViewer.this));
			if (rolesPanel == null) rolesPanel = register(new RolesPanel(box()).<RolesPanel>id("a_1036662658").owner(AbstractIdentityViewer.this));
		}

		public class FeaturesPanel extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public IdentityViewer.MainLayer.FeaturesPanel. FeaturesTitle featuresTitle;
			public IdentityViewer.MainLayer.FeaturesPanel. FeaturesStamp featuresStamp;

			public FeaturesPanel(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (featuresTitle == null) featuresTitle = register(new FeaturesTitle(box()).<FeaturesTitle>id("a1881263948").owner(AbstractIdentityViewer.this));
				if (featuresStamp == null) featuresStamp = register(new FeaturesStamp(box()).<FeaturesStamp>id("a1880649911").owner(AbstractIdentityViewer.this));
			}

			public class FeaturesTitle extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public FeaturesTitle(B box) {
					super(box);
					_value("Features");
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class FeaturesStamp extends io.intino.alexandria.ui.displays.components.Multiple<Box, PropertyViewer, java.lang.Void>  {

				public FeaturesStamp(Box box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}
				@Override
				public PropertyViewer add(java.lang.Void value) {
					PropertyViewer child = new PropertyViewer(box());
					child.id(java.util.UUID.randomUUID().toString());
					add(child, "featuresStamp");
					return child;
				}
				public void clear() {
				    super.clear("featuresStamp");
				}
			}
		}

		public class CredentialsPanel extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public IdentityViewer.MainLayer.CredentialsPanel. CredentialsTitle credentialsTitle;
			public IdentityViewer.MainLayer.CredentialsPanel. CredentialsStamp credentialsStamp;

			public CredentialsPanel(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (credentialsTitle == null) credentialsTitle = register(new CredentialsTitle(box()).<CredentialsTitle>id("a_1007281508").owner(AbstractIdentityViewer.this));
				if (credentialsStamp == null) credentialsStamp = register(new CredentialsStamp(box()).<CredentialsStamp>id("a_1007895545").owner(AbstractIdentityViewer.this));
			}

			public class CredentialsTitle extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public CredentialsTitle(B box) {
					super(box);
					_value("Credentials");
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class CredentialsStamp extends io.intino.alexandria.ui.displays.components.Multiple<Box, PropertyViewer, java.lang.Void>  {

				public CredentialsStamp(Box box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}
				@Override
				public PropertyViewer add(java.lang.Void value) {
					PropertyViewer child = new PropertyViewer(box());
					child.id(java.util.UUID.randomUUID().toString());
					add(child, "credentialsStamp");
					return child;
				}
				public void clear() {
				    super.clear("credentialsStamp");
				}
			}
		}

		public class RolesPanel extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public IdentityViewer.MainLayer.RolesPanel. RolesTitle rolesTitle;
			public IdentityViewer.MainLayer.RolesPanel. RolesStamp rolesStamp;

			public RolesPanel(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (rolesTitle == null) rolesTitle = register(new RolesTitle(box()).<RolesTitle>id("a_1687272452").owner(AbstractIdentityViewer.this));
				if (rolesStamp == null) rolesStamp = register(new RolesStamp(box()).<RolesStamp>id("a_1687886489").owner(AbstractIdentityViewer.this));
			}

			public class RolesTitle extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public RolesTitle(B box) {
					super(box);
					_value("Roles");
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class RolesStamp extends io.intino.alexandria.ui.displays.components.Multiple<Box, PropertyViewer, java.lang.Void>  {

				public RolesStamp(Box box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}
				@Override
				public PropertyViewer add(java.lang.Void value) {
					PropertyViewer child = new PropertyViewer(box());
					child.id(java.util.UUID.randomUUID().toString());
					add(child, "rolesStamp");
					return child;
				}
				public void clear() {
				    super.clear("rolesStamp");
				}
			}
		}
	}
}

==> identity-editor-2.0.2-sources.jar: io/intino/amidas/identityeditor/box/ui/displays/templates/AbstractIdentityViewer.java <==
package io.intino.amidas.identityeditor.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.amidas.identityeditor.box.ui.*;

import io.intino.amidas.identityeditor.box.IdentityEditorBox;

import io.intino.amidas.identityeditor.box.ui.displays.templates.*;








import io.intino.amidas.identityeditor.box.ui.displays.notifiers.IdentityViewerNotifier;

public abstract class AbstractIdentityViewer<DN extends IdentityViewerNotifier, B extends Box> extends io.intino.alexandria.ui.displays.components.Template<DN, java.lang.Void, B> {
	public EmptyLayer emptyLayer;
	public IdentityViewer.EmptyLayer. EmptyText emptyText;
	public LoadingLayer loadingLayer;
	public IdentityViewer.LoadingLayer. _7_92_1339785223 _7_92_1339785223;
	public MainLayer mainLayer;
	public IdentityViewer.MainLayer. FeaturesPanel featuresPanel;
	public IdentityViewer.MainLayer.FeaturesPanel. FeaturesTitle featuresTitle;
	public IdentityViewer.MainLayer.FeaturesPanel. FeaturesStamp featuresStamp;
	public IdentityViewer.MainLayer. CredentialsPanel credentialsPanel;
	public IdentityViewer.MainLayer.CredentialsPanel. CredentialsTitle credentialsTitle;
	public IdentityViewer.MainLayer.CredentialsPanel. CredentialsStamp credentialsStamp;
	public IdentityViewer.MainLayer. RolesPanel rolesPanel;
	public IdentityViewer.MainLayer.RolesPanel. RolesTitle rolesTitle;
	public IdentityViewer.MainLayer.RolesPanel. RolesStamp rolesStamp;

	public AbstractIdentityViewer(B box) {
		super(box);
		id("identityViewer");
	}

	@Override
	public void init() {
		super.init();
		if (emptyLayer == null) emptyLayer = register(new EmptyLayer(box()).<EmptyLayer>id("a_755652684").owner(AbstractIdentityViewer.this));
		if (emptyLayer != null) emptyText = emptyLayer.emptyText;
		if (loadingLayer == null) loadingLayer = register(new LoadingLayer(box()).<LoadingLayer>id("a1199389989").owner(AbstractIdentityViewer.this));
		if (loadingLayer != null) _7_92_1339785223 = loadingLayer._7_92_1339785223;
		if (mainLayer == null) mainLayer = register(new MainLayer(box()).<MainLayer>id("a_258747032").owner(AbstractIdentityViewer.this));
		if (mainLayer != null) featuresPanel = mainLayer.featuresPanel;
		if (featuresPanel != null) featuresTitle = mainLayer.featuresPanel.featuresTitle;
		if (featuresPanel != null) featuresStamp = mainLayer.featuresPanel.featuresStamp;
		if (mainLayer != null) credentialsPanel = mainLayer.credentialsPanel;
		if (credentialsPanel != null) credentialsTitle = mainLayer.credentialsPanel.credentialsTitle;
		if (credentialsPanel != null) credentialsStamp = mainLayer.credentialsPanel.credentialsStamp;
		if (mainLayer != null) rolesPanel = mainLayer.rolesPanel;
		if (rolesPanel != null) rolesTitle = mainLayer.rolesPanel.rolesTitle;
		if (rolesPanel != null) rolesStamp = mainLayer.rolesPanel.rolesStamp;
	}

	@Override
	public void remove() {
		super.remove();
		if (emptyLayer != null) emptyLayer.unregister();
		if (loadingLayer != null) loadingLayer.unregister();
		if (mainLayer != null) mainLayer.unregister();
	}

	public class EmptyLayer extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public IdentityViewer.EmptyLayer. EmptyText emptyText;

		public EmptyLayer(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (emptyText == null) emptyText = register(new EmptyText(box()).<EmptyText>id("a_1732484785").owner(AbstractIdentityViewer.this));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (emptyText != null) emptyText.unregister();
		}

		public class EmptyText extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public EmptyText(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
				super.unregister();
			}
		}
	}

	public class LoadingLayer extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public IdentityViewer.LoadingLayer. _7_92_1339785223 _7_92_1339785223;

		public LoadingLayer(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_7_92_1339785223 == null) _7_92_1339785223 = register(new _7_92_1339785223(box()).<_7_92_1339785223>id("a_196349312").owner(AbstractIdentityViewer.this));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (_7_92_1339785223 != null) _7_92_1339785223.unregister();
		}

		public class _7_92_1339785223 extends io.intino.alexandria.ui.displays.components.Spinner<io.intino.alexandria.ui.displays.notifiers.SpinnerNotifier, B>  {

			public _7_92_1339785223(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
				super.unregister();
			}
		}
	}

	public class MainLayer extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public IdentityViewer.MainLayer. FeaturesPanel featuresPanel;
		public IdentityViewer.MainLayer. CredentialsPanel credentialsPanel;
		public IdentityViewer.MainLayer. RolesPanel rolesPanel;

		public MainLayer(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (featuresPanel == null) featuresPanel = register(new FeaturesPanel(box()).<FeaturesPanel>id("a_1348836048").owner(AbstractIdentityViewer.this));
			if (credentialsPanel == null) credentialsPanel = register(new CredentialsPanel(box()).<CredentialsPanel>id("a_1794867617").owner(AbstractIdentityViewer.this));
			if (rolesPanel == null) rolesPanel = register(new RolesPanel(box()).<RolesPanel>id("a_1036662658").owner(AbstractIdentityViewer.this));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (featuresPanel != null) featuresPanel.unregister();
			if (credentialsPanel != null) credentialsPanel.unregister();
			if (rolesPanel != null) rolesPanel.unregister();
		}

		public class FeaturesPanel extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public IdentityViewer.MainLayer.FeaturesPanel. FeaturesTitle featuresTitle;
			public IdentityViewer.MainLayer.FeaturesPanel. FeaturesStamp featuresStamp;

			public FeaturesPanel(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (featuresTitle == null) featuresTitle = register(new FeaturesTitle(box()).<FeaturesTitle>id("a1881263948").owner(AbstractIdentityViewer.this));
				if (featuresStamp == null) featuresStamp = AbstractIdentityViewer.this.featuresStamp = register(new FeaturesStamp(box()).<FeaturesStamp>id("a1880649911").owner(AbstractIdentityViewer.this));
			}

			@Override
			public void unregister() {
				super.unregister();
				if (featuresTitle != null) featuresTitle.unregister();
				if (featuresStamp != null) featuresStamp.unregister();
			}

			public class FeaturesTitle extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public FeaturesTitle(B box) {
					super(box);
					_value("Features");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
					super.unregister();
				}
			}

			public class FeaturesStamp extends io.intino.alexandria.ui.displays.components.Multiple<Box,PropertyViewer, java.lang.Void> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<Box,PropertyViewer, java.lang.Void> {

				public FeaturesStamp(Box box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
					super.unregister();
				}

				@Override
				public PropertyViewer add(java.lang.Void value) {
					PropertyViewer child = new PropertyViewer(box());
					child.id(java.util.UUID.randomUUID().toString());
					add(child, "featuresStamp");
					notifyAdd(child);
					return child;
				}
				@Override
				public void remove(PropertyViewer child) {
					removeChild(child, "featuresStamp");
				}
				public void clear() {
					super.clear("featuresStamp");
				}
			}
		}

		public class CredentialsPanel extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public IdentityViewer.MainLayer.CredentialsPanel. CredentialsTitle credentialsTitle;
			public IdentityViewer.MainLayer.CredentialsPanel. CredentialsStamp credentialsStamp;

			public CredentialsPanel(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (credentialsTitle == null) credentialsTitle = register(new CredentialsTitle(box()).<CredentialsTitle>id("a_1007281508").owner(AbstractIdentityViewer.this));
				if (credentialsStamp == null) credentialsStamp = AbstractIdentityViewer.this.credentialsStamp = register(new CredentialsStamp(box()).<CredentialsStamp>id("a_1007895545").owner(AbstractIdentityViewer.this));
			}

			@Override
			public void unregister() {
				super.unregister();
				if (credentialsTitle != null) credentialsTitle.unregister();
				if (credentialsStamp != null) credentialsStamp.unregister();
			}

			public class CredentialsTitle extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public CredentialsTitle(B box) {
					super(box);
					_value("Credentials");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
					super.unregister();
				}
			}

			public class CredentialsStamp extends io.intino.alexandria.ui.displays.components.Multiple<Box,PropertyViewer, java.lang.Void> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<Box,PropertyViewer, java.lang.Void> {

				public CredentialsStamp(Box box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
					super.unregister();
				}

				@Override
				public PropertyViewer add(java.lang.Void value) {
					PropertyViewer child = new PropertyViewer(box());
					child.id(java.util.UUID.randomUUID().toString());
					add(child, "credentialsStamp");
					notifyAdd(child);
					return child;
				}
				@Override
				public void remove(PropertyViewer child) {
					removeChild(child, "credentialsStamp");
				}
				public void clear() {
					super.clear("credentialsStamp");
				}
			}
		}

		public class RolesPanel extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public IdentityViewer.MainLayer.RolesPanel. RolesTitle rolesTitle;
			public IdentityViewer.MainLayer.RolesPanel. RolesStamp rolesStamp;

			public RolesPanel(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (rolesTitle == null) rolesTitle = register(new RolesTitle(box()).<RolesTitle>id("a_1687272452").owner(AbstractIdentityViewer.this));
				if (rolesStamp == null) rolesStamp = AbstractIdentityViewer.this.rolesStamp = register(new RolesStamp(box()).<RolesStamp>id("a_1687886489").owner(AbstractIdentityViewer.this));
			}

			@Override
			public void unregister() {
				super.unregister();
				if (rolesTitle != null) rolesTitle.unregister();
				if (rolesStamp != null) rolesStamp.unregister();
			}

			public class RolesTitle extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public RolesTitle(B box) {
					super(box);
					_value("Roles");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
					super.unregister();
				}
			}

			public class RolesStamp extends io.intino.alexandria.ui.displays.components.Multiple<Box,PropertyViewer, java.lang.Void> implements io.intino.alexandria.ui.displays.components.multiple.NonCollapsable<Box,PropertyViewer, java.lang.Void> {

				public RolesStamp(Box box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
					super.unregister();
				}

				@Override
				public PropertyViewer add(java.lang.Void value) {
					PropertyViewer child = new PropertyViewer(box());
					child.id(java.util.UUID.randomUUID().toString());
					add(child, "rolesStamp");
					notifyAdd(child);
					return child;
				}
				@Override
				public void remove(PropertyViewer child) {
					removeChild(child, "rolesStamp");
				}
				public void clear() {
					super.clear("rolesStamp");
				}
			}
		}
	}
}
